==> veracrypt_1.17.orig.tar.bz2: src/Common/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Common.rc
//
#define IDI_TRUECRYPT_ICON              501
#define IDI_TRUECRYPT_VOL_ICON          502
#define IDD_BENCHMARK_DLG               503
#define IDD_MOUNT_OPTIONS               504
#define IDD_KEYFILES                    505
#define IDR_LANGUAGE                    506
#define IDI_TRUECRYPT                   507
#define IDD_ABOUT_DLG                   508
#define IDD_COMMANDHELP_DLG             509
#define IDD_RAWDEVICES_DLG              510
#define IDC_HOMEPAGE                    511
#define IDR_COMMON_RSRC_HEADER          512
#define IDD_LANGUAGE                    513
#define IDD_CIPHER_TEST_DLG             514
#define IDR_LICENSE                     515
#define IDD_AUXILIARY_DLG               516
#define IDB_TEXTUAL_LOGO_BKG            517
#define IDB_TEXTUAL_LOGO_96DPI          518
#define IDB_TEXTUAL_LOGO_288DPI         519
#define IDR_BOOT_SECTOR                 520
#define IDR_BOOT_SECTOR_AES             521
#define IDR_BOOT_SECTOR_SERPENT         522
#define IDR_BOOT_SECTOR_TWOFISH         523
#define IDR_BOOT_LOADER_DECOMPRESSOR    524
#define IDR_BOOT_LOADER                 525
#define IDR_BOOT_LOADER_AES             526
#define IDR_BOOT_LOADER_SERPENT         527
#define IDR_BOOT_LOADER_TWOFISH         528
#define IDR_RESCUE_BOOT_SECTOR          529
#define IDR_RESCUE_BOOT_SECTOR_AES      530
#define IDR_RESCUE_BOOT_SECTOR_SERPENT  531
#define IDR_RESCUE_BOOT_SECTOR_TWOFISH  532
#define IDR_RESCUE_LOADER               533
#define IDR_RESCUE_LOADER_AES           534
#define IDR_RESCUE_LOADER_SERPENT       535
#define IDR_RESCUE_LOADER_TWOFISH       536
#define IDD_TOKEN_PASSWORD              537
#define IDD_TOKEN_KEYFILES              538
#define IDD_NEW_TOKEN_KEYFILE           539
#define IDD_RANDOM_POOL_ENRICHMENT      540
#define IDI_TRUECRYPT_MOUNTED_ICON      541
#define IDR_BOOT_SECTOR_SHA2            542
#define IDR_BOOT_SECTOR_AES_SHA2        543
#define IDR_BOOT_SECTOR_SERPENT_SHA2    544
#define IDR_BOOT_SECTOR_TWOFISH_SHA2    545
#define IDR_BOOT_LOADER_SHA2            546
#define IDR_BOOT_LOADER_AES_SHA2        547
#define IDR_BOOT_LOADER_SERPENT_SHA2    548
#define IDR_BOOT_LOADER_TWOFISH_SHA2    549
#define IDR_RESCUE_BOOT_SECTOR_SHA2     550
#define IDR_RESCUE_BOOT_SECTOR_AES_SHA2 551
#define IDR_RESCUE_BOOT_SECTOR_SERPENT_SHA2 552
#define IDR_RESCUE_BOOT_SECTOR_TWOFISH_SHA2 553
#define IDR_RESCUE_LOADER_SHA2          554
#define IDR_RESCUE_LOADER_AES_SHA2      555
#define IDR_RESCUE_LOADER_SERPENT_SHA2  556
#define IDR_RESCUE_LOADER_TWOFISH_SHA2  557
#define IDC_HW_AES_LABEL_LINK           5000
#define IDC_HW_AES                      5001
#define IDC_PARALLELIZATION_LABEL_LINK  5002
#define IDC_PARALLELIZATION             5003
#define IDT_TOKEN_PASSWORD              5004
#define IDC_PRINT                       5005
#define IDC_KEY                         5006
#define IDC_PLAINTEXT                   5007
#define IDC_CIPHERTEXT                  5008
#define IDC_INFO_BOX_TEXT               5009
#define IDC_SECONDARY_KEY               5010
#define IDD_TEXT_INFO_DIALOG_BOX_DLG    5011
#define IDC_TEST_DATA_UNIT_NUMBER       5012
#define IDD_KEYFILE_GENERATOR           5013
#define IDC_CIPHER                      5014
#define IDD_MULTI_CHOICE_DLG            5015
#define IDC_TEST_BLOCK_NUMBER           5016
#define IDD_STATIC_MODELESS_WAIT_DLG    5017
#define IDC_POOL_CONTENTS               5018
#define IDC_PRF_ID                      5019
#define IDC_KEY_SIZE                    5020
#define IDC_PLAINTEXT_SIZE              5021
#define IDC_REDTICK                     5022
#define IDC_TESTS_MESSAGE               5023
#define IDC_RESET                       5024
#define IDC_AUTO                        5025
#define IDC_DECRYPT                     5026
#define IDT_TEST_KEY                    5027
#define IDT_TEST_PLAINTEXT              5028
#define IDT_PRF                         5029
#define IDT_XTS_MODE                    5030
#define IDT_TEST_CIPHERTEXT             5031
#define IDT_KEY                         5032
#define IDT_PLAINTEXT                   5033
#define IDC_ENCRYPT                     5034
#define IDT_KEY_UNIT                    5035
#define IDT_CIPHER                      5036
#define IDT_PLAINTEXT_SIZE_UNIT         5037
#define IDC_DEVICELIST                  5038
#define IDT_TEST_BLOCK_NUMBER           5039
#define IDT_SECONDARY_KEY               5040
#define IDC_PERFORM_BENCHMARK           5041
#define IDT_TEST_DATA_UNIT_NUMBER       5042
#define IDC_KEYFILES_HIDVOL_PROT        5043
#define IDC_KEYLIST                     5044
#define IDC_ABOUT_BKG                   5045
#define IDT_ABOUT_VERSION               5046
#define IDT_BOX_BENCHMARK_INFO          5047
#define IDC_ABOUT_CREDITS               5048
#define IDT_SORT_METHOD                 5049
#define IDC_MOUNT_READONLY              5050
#define IDC_MOUNT_REMOVABLE             5051
#define IDC_PROTECT_HIDDEN_VOL          5052
#define IDC_COMMANDHELP_TEXT            5053
#define IDC_USE_EMBEDDED_HEADER_BAK     5054
#define IDC_MOUNT_SYSENC_PART_WITHOUT_PBA 5055
#define IDT_HIDDEN_PROT_PASSWD          5056
#define IDC_RESULTS                     5057
#define IDC_KEYADD                      5058
#define IDC_KEYREMOVE                   5059
#define IDC_KEYREMOVEALL                5060
#define IDC_KEYFILES_ENABLE             5061
#define IDT_HIDDEN_VOL_PROTECTION       5062
#define IDC_ADD_KEYFILE_PATH            5063
#define IDC_BENCHMARK_BUFFER_SIZE       5064
#define IDC_SHOW_PASSWORD_MO            5065
#define IDC_GENERATE_KEYFILE            5066
#define IDC_BENCHMARK_SORT_METHOD       5067
#define IDC_PASSWORD_PROT_HIDVOL        5068
#define IDT_BUFFER_SIZE                 5069
#define IDC_LANGLIST                    5070
#define IDC_KEYFILES_ENABLE_HIDVOL_PROT 5071
#define IDT_KEYFILES_NOTE               5072
#define IDT_KEYFILE_WARNING             5073
#define IDT_KEYFILE_GENERATOR_NOTE      5074
#define IDC_GENERATE_AND_SAVE_KEYFILE   5075
#define IDT_POOL_CONTENTS               5076
#define IDC_GET_LANG_PACKS              5077
#define IDT_LANGPACK_AUTHORS            5078
#define IDC_LANGPACK_CREDITS            5079
#define IDC_LANGPACK_VERSION            5080
#define IDT_ACTIVE_LANG_PACK            5081
#define IDC_DISPLAY_POOL_CONTENTS       5082
#define IDC_XTS_MODE_ENABLED            5083
#define IDC_MULTI_CHOICE_MSG            5084
#define IDC_CHOICE1                     5085
#define IDC_CHOICE5                     5086
#define IDC_CHOICE2                     5087
#define IDC_CHOICE3                     5088
#define IDC_CHOICE4                     5089
#define IDC_CHOICE6                     5090
#define IDC_CHOICE7                     5091
#define IDC_CHOICE8                     5092
#define IDC_CHOICE9                     5093
#define IDC_CHOICE10                    5094
#define IDC_MC_DLG_HR1                  5095
#define IDC_MC_DLG_HR2                  5096
#define IDC_LINK_HIDVOL_PROTECTION_INFO 5097
#define IDC_LINK_KEYFILES_INFO          5098
#define IDC_TEXTUAL_LOGO_IMG            5099
#define IDC_ASPECT_RATIO_CALIBRATION_BOX 5100
#define IDC_ABOUT_LOGO_AREA             5101
#define IDC_TOKEN_PASSWORD              5102
#define IDC_TOKEN_FILE_LIST             5103
#define IDC_TOKEN_FILES_ADD             5104
#define IDC_EXPORT                      5105
#define IDC_DELETE                      5106
#define IDC_IMPORT_KEYFILE              5107
#define IDC_SELECTED_TOKEN              5108
#define IDT_SECURITY_TOKEN              5109
#define IDT_TOKEN_KEYFILE_NAME          5110
#define IDC_TOKEN_KEYFILE_NAME          5111
#define IDT_TOKEN_PASSWORD_INFO         5112
#define IDT_RANDOM_POOL_ENRICHMENT_NOTE 5113
#define IDC_CONTINUE                    5114
#define IDT_ABOUT_RELEASE               5115
#define IDT_STATIC_MODELESS_WAIT_DLG_INFO 5116
#define IDT_NUMBER_KEYFILES             5117
#define IDC_NUMBER_KEYFILES             5118
#define IDT_KEYFILES_BASE_NAME          5119
#define IDC_KEYFILES_BASE_NAME          5120
#define IDC_KEYFILES_SIZE               5121
#define IDC_KEYFILES_RANDOM_SIZE        5122
#define IDT_KEYFILES_SIZE               5123
#define IDD_STATIC_MODAL_WAIT_DLG       5124
#define IDT_STATIC_MODAL_WAIT_DLG_INFO  5125
#define IDC_WAIT_PROGRESS_BAR           5126
#define IDC_PKCS5_PRF_ID                5127
#define IDT_PKCS5_PRF                   5128
#define IDT_PIM                         5129
#define IDC_PIM                         5130
#define IDC_PIM_HELP                    5131
#define IDC_PIM_ENABLE                  5132
#define IDC_VOLUME_LABEL                5133
#define IDT_VOLUME_LABEL                5134
#define IDC_KEYFILES_TRY_EMPTY_PASSWORD 5135
#define IDC_ENTROPY_BAR                 5136
#define IDT_ENTROPY_BAR                 5137

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        558
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         5138
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> veracrypt_1.26.7.orig.tar.bz2: src/Common/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Common.rc
//
#define IDI_TRUECRYPT_ICON              501
#define IDI_TRUECRYPT_VOL_ICON          502
#define IDD_BENCHMARK_DLG               503
#define IDD_MOUNT_OPTIONS               504
#define IDD_KEYFILES                    505
#define IDR_LANGUAGE                    506
#define IDI_TRUECRYPT                   507
#define IDD_ABOUT_DLG                   508
#define IDD_COMMANDHELP_DLG             509
#define IDD_RAWDEVICES_DLG              510
#define IDC_HOMEPAGE                    511
#define IDR_COMMON_RSRC_HEADER          512
#define IDD_LANGUAGE                    513
#define IDD_CIPHER_TEST_DLG             514
#define IDR_LICENSE                     515
#define IDD_AUXILIARY_DLG               516
#define IDB_TEXTUAL_LOGO_BKG            517
#define IDB_TEXTUAL_LOGO_96DPI          518
#define IDB_TEXTUAL_LOGO_288DPI         519
#define IDR_BOOT_SECTOR                 520
#define IDR_BOOT_SECTOR_AES             521
#define IDR_BOOT_SECTOR_SERPENT         522
#define IDR_BOOT_SECTOR_TWOFISH         523
#define IDR_BOOT_LOADER_DECOMPRESSOR    524
#define IDR_BOOT_LOADER                 525
#define IDR_BOOT_LOADER_AES             526
#define IDR_BOOT_LOADER_SERPENT         527
#define IDR_BOOT_LOADER_TWOFISH         528
#define IDR_RESCUE_BOOT_SECTOR          529
#define IDR_RESCUE_BOOT_SECTOR_AES      530
#define IDR_RESCUE_BOOT_SECTOR_SERPENT  531
#define IDR_RESCUE_BOOT_SECTOR_TWOFISH  532
#define IDR_RESCUE_LOADER               533
#define IDR_RESCUE_LOADER_AES           534
#define IDR_RESCUE_LOADER_SERPENT       535
#define IDR_RESCUE_LOADER_TWOFISH       536
#define IDD_TOKEN_PASSWORD              537
#define IDD_TOKEN_KEYFILES              538
#define IDD_NEW_TOKEN_KEYFILE           539
#define IDD_RANDOM_POOL_ENRICHMENT      540
#define IDI_TRUECRYPT_MOUNTED_ICON      541
#define IDR_BOOT_SECTOR_SHA2            542
#define IDR_BOOT_SECTOR_AES_SHA2        543
#define IDR_BOOT_SECTOR_SERPENT_SHA2    544
#define IDR_BOOT_SECTOR_TWOFISH_SHA2    545
#define IDR_BOOT_LOADER_SHA2            546
#define IDR_BOOT_LOADER_AES_SHA2        547
#define IDR_BOOT_LOADER_SERPENT_SHA2    548
#define IDR_BOOT_LOADER_TWOFISH_SHA2    549
#define IDR_RESCUE_BOOT_SECTOR_SHA2     550
#define IDR_RESCUE_BOOT_SECTOR_AES_SHA2 551
#define IDR_RESCUE_BOOT_SECTOR_SERPENT_SHA2 552
#define IDR_RESCUE_BOOT_SECTOR_TWOFISH_SHA2 553
#define IDR_RESCUE_LOADER_SHA2          554
#define IDR_RESCUE_LOADER_AES_SHA2      555
#define IDR_RESCUE_LOADER_SERPENT_SHA2  556
#define IDR_RESCUE_LOADER_TWOFISH_SHA2  557
#define IDR_BOOT_SECTOR_CAMELLIA        558
#define IDR_BOOT_LOADER_CAMELLIA        559
#define IDR_RESCUE_BOOT_SECTOR_CAMELLIA 560
#define IDR_RESCUE_LOADER_CAMELLIA      561
#define IDR_BOOT_SECTOR_CAMELLIA_SHA2   562
#define IDR_BOOT_LOADER_CAMELLIA_SHA2   563
#define IDR_RESCUE_BOOT_SECTOR_CAMELLIA_SHA2 564
#define IDR_RESCUE_LOADER_CAMELLIA_SHA2 565
#define IDR_EFI_DCSBOOT                 566
#define IDR_EFI_DCSINT                  567
#define IDR_EFI_DCSCFG                  568
#define IDR_EFI_LEGACYSPEAKER           569
#define IDR_EFI_DCSBML                  570
#define IDR_EFI_DCSRE                   571
#define IDR_EFI_DCSBOOT32               572
#define IDR_EFI_DCSINT32                573
#define IDR_EFI_DCSCFG32                574
#define IDR_EFI_LEGACYSPEAKER32         575
#define IDR_EFI_DCSBML32                576
#define IDR_EFI_DCSRE32                 577
#define IDR_EFI_DCSINFO                 578
#define IDR_EFI_DCSINFO32               579
#define IDC_HW_AES_LABEL_LINK           5000
#define IDC_HW_AES                      5001
#define IDC_PARALLELIZATION_LABEL_LINK  5002
#define IDC_PARALLELIZATION             5003
#define IDT_TOKEN_PASSWORD              5004
#define IDC_PRINT                       5005
#define IDC_KEY                         5006
#define IDC_PLAINTEXT                   5007
#define IDC_CIPHERTEXT                  5008
#define IDC_INFO_BOX_TEXT               5009
#define IDC_SECONDARY_KEY               5010
#define IDD_TEXT_INFO_DIALOG_BOX_DLG    5011
#define IDC_TEST_DATA_UNIT_NUMBER       5012
#define IDD_KEYFILE_GENERATOR           5013
#define IDC_CIPHER                      5014
#define IDD_MULTI_CHOICE_DLG            5015
#define IDC_TEST_BLOCK_NUMBER           5016
#define IDD_STATIC_MODELESS_WAIT_DLG    5017
#define IDC_POOL_CONTENTS               5018
#define IDC_PRF_ID                      5019
#define IDC_KEY_SIZE                    5020
#define IDC_PLAINTEXT_SIZE              5021
#define IDC_REDTICK                     5022
#define IDC_TESTS_MESSAGE               5023
#define IDC_RESET                       5024
#define IDC_AUTO                        5025
#define IDC_DECRYPT                     5026
#define IDT_TEST_KEY                    5027
#define IDT_TEST_PLAINTEXT              5028
#define IDT_PRF                         5029
#define IDT_XTS_MODE                    5030
#define IDT_TEST_CIPHERTEXT             5031
#define IDT_KEY                         5032
#define IDT_PLAINTEXT                   5033
#define IDC_ENCRYPT                     5034
#define IDT_KEY_UNIT                    5035
#define IDT_CIPHER                      5036
#define IDT_PLAINTEXT_SIZE_UNIT         5037
#define IDC_DEVICELIST                  5038
#define IDT_TEST_BLOCK_NUMBER           5039
#define IDT_SECONDARY_KEY               5040
#define IDC_PERFORM_BENCHMARK           5041
#define IDT_TEST_DATA_UNIT_NUMBER       5042
#define IDC_KEYFILES_HIDVOL_PROT        5043
#define IDC_KEYLIST                     5044
#define IDC_ABOUT_BKG                   5045
#define IDT_ABOUT_VERSION               5046
#define IDT_BOX_BENCHMARK_INFO          5047
#define IDC_ABOUT_CREDITS               5048
#define IDT_SORT_METHOD                 5049
#define IDC_MOUNT_READONLY              5050
#define IDC_MOUNT_REMOVABLE             5051
#define IDC_PROTECT_HIDDEN_VOL          5052
#define IDC_COMMANDHELP_TEXT            5053
#define IDC_USE_EMBEDDED_HEADER_BAK     5054
#define IDC_MOUNT_SYSENC_PART_WITHOUT_PBA 5055
#define IDT_HIDDEN_PROT_PASSWD          5056
#define IDC_RESULTS                     5057
#define IDC_KEYADD                      5058
#define IDC_KEYREMOVE                   5059
#define IDC_KEYREMOVEALL                5060
#define IDC_KEYFILES_ENABLE             5061
#define IDT_HIDDEN_VOL_PROTECTION       5062
#define IDC_ADD_KEYFILE_PATH            5063
#define IDC_BENCHMARK_BUFFER_SIZE       5064
#define IDC_SHOW_PASSWORD_MO            5065
#define IDC_GENERATE_KEYFILE            5066
#define IDC_BENCHMARK_SORT_METHOD       5067
#define IDC_PASSWORD_PROT_HIDVOL        5068
#define IDT_BUFFER_SIZE                 5069
#define IDC_LANGLIST                    5070
#define IDC_KEYFILES_ENABLE_HIDVOL_PROT 5071
#define IDT_KEYFILES_NOTE               5072
#define IDT_KEYFILE_WARNING             5073
#define IDT_KEYFILE_GENERATOR_NOTE      5074
#define IDC_GENERATE_AND_SAVE_KEYFILE   5075
#define IDT_POOL_CONTENTS               5076
#define IDC_GET_LANG_PACKS              5077
#define IDT_LANGPACK_AUTHORS            5078
#define IDC_LANGPACK_CREDITS            5079
#define IDC_LANGPACK_VERSION            5080
#define IDT_ACTIVE_LANG_PACK            5081
#define IDC_DISPLAY_POOL_CONTENTS       5082
#define IDC_XTS_MODE_ENABLED            5083
#define IDC_MULTI_CHOICE_MSG            5084
#define IDC_CHOICE1                     5085
#define IDC_CHOICE5                     5086
#define IDC_CHOICE2                     5087
#define IDC_CHOICE3                     5088
#define IDC_CHOICE4                     5089
#define IDC_CHOICE6                     5090
#define IDC_CHOICE7                     5091
#define IDC_CHOICE8                     5092
#define IDC_CHOICE9                     5093
#define IDC_CHOICE10                    5094
#define IDC_MC_DLG_HR1                  5095
#define IDC_MC_DLG_HR2                  5096
#define IDC_LINK_HIDVOL_PROTECTION_INFO 5097
#define IDC_LINK_KEYFILES_INFO          5098
#define IDC_TEXTUAL_LOGO_IMG            5099
#define IDC_ASPECT_RATIO_CALIBRATION_BOX 5100
#define IDC_ABOUT_LOGO_AREA             5101
#define IDC_TOKEN_PASSWORD              5102
#define IDC_TOKEN_FILE_LIST             5103
#define IDC_TOKEN_FILES_ADD             5104
#define IDC_EXPORT                      5105
#define IDC_DELETE                      5106
#define IDC_IMPORT_KEYFILE              5107
#define IDC_SELECTED_TOKEN              5108
#define IDT_SECURITY_TOKEN              5109
#define IDT_TOKEN_KEYFILE_NAME          5110
#define IDC_TOKEN_KEYFILE_NAME          5111
#define IDT_TOKEN_PASSWORD_INFO         5112
#define IDT_RANDOM_POOL_ENRICHMENT_NOTE 5113
#define IDC_CONTINUE                    5114
#define IDT_ABOUT_RELEASE               5115
#define IDT_STATIC_MODELESS_WAIT_DLG_INFO 5116
#define IDT_NUMBER_KEYFILES             5117
#define IDC_NUMBER_KEYFILES             5118
#define IDT_KEYFILES_BASE_NAME          5119
#define IDC_KEYFILES_BASE_NAME          5120
#define IDC_KEYFILES_SIZE               5121
#define IDC_KEYFILES_RANDOM_SIZE        5122
#define IDT_KEYFILES_SIZE               5123
#define IDD_STATIC_MODAL_WAIT_DLG       5124
#define IDT_STATIC_MODAL_WAIT_DLG_INFO  5125
#define IDC_WAIT_PROGRESS_BAR           5126
#define IDC_PKCS5_PRF_ID                5127
#define IDT_PKCS5_PRF                   5128
#define IDT_PIM                         5129
#define IDC_PIM                         5130
#define IDC_PIM_HELP                    5131
#define IDC_PIM_ENABLE                  5132
#define IDC_VOLUME_LABEL                5133
#define IDT_VOLUME_LABEL                5134
#define IDC_KEYFILES_TRY_EMPTY_PASSWORD 5135
#define IDC_ENTROPY_BAR                 5136
#define IDT_ENTROPY_BAR                 5137
#define IDT_BENCHMARK                   5138
#define IDC_BENCHMARK_LIST              5139
#define IDC_BENCHMARK_PREBOOT           5140
#define IDD_TEXT_EDIT_DLG               5141
#define IDC_DISABLE_MOUNT_MANAGER       5142
#define IDC_KEYFILES_SIZE_UNIT          5143
#define IDC_LINK_KEYFILES_EXTENSIONS_WARNING 5144
#define IDC_DISABLE_MEMORY_PROTECTION   5145
#define IDC_DISABLE_MEMORY_PROTECTION_HELP   5146

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        578
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         5147
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
